... s a handful of fixes. The biggest fix is for a memory leak introduced in Django 1.5. Under certain circumstances, repeated iteration over querysets could leak memory - sometimes quite a bit of it. If you'd like more information, the details are in our tic ... スノート March bugfix release It's completely backwards compatible handful biggest introduced certain circumstances repeated iteration over querysets sometimes quite like more クイック検索 Last update: 2026年10月09日 « previous | up | next » ... ... ong been possible (but not officially supported) on MySQL and PostgreSQL, and is now also available on Oracle. The default iteration count for the PBKDF2 password hasher has been increased by 20%. This backwards compatible change will not affect existing ... ed django.contrib.auth.hashers.PBKDF2PasswordHasher to change the default value. Passwords will be upgraded to use the new iteration count as necessary. Backwards incompatible changes in 1.6 ¶ 警告 In addition to the changes outlined in this section, be s ... ed to be aware of what's described in Munging of help text of model form fields for ManyToManyField fields below. QuerySet iteration ¶ The QuerySet iteration was changed to immediately convert all fetched rows to Model objects. In Django 1.5 and earlier t ... ... 1.4.9, we've reverted this change and instead improved the speed of our PBKDF2 algorithm by not rehashing the key on every iteration. バグ修正 ¶ Fixed a data corruption bug with datetime_safe.datetime.combine (#21256). 目次 Django 1.4.9 リリースノート Rea ... ... ong been possible (but not officially supported) on MySQL and PostgreSQL, and is now also available on Oracle. The default iteration count for the PBKDF2 password hasher has been increased by 20%. This backwards compatible change will not affect existing ... ed django.contrib.auth.hashers.PBKDF2PasswordHasher to change the default value. Passwords will be upgraded to use the new iteration count as necessary. Backwards incompatible changes in 1.6 ¶ 警告 In addition to the changes outlined in this section, be s ... ed to be aware of what's described in Munging of help text of model form fields for ManyToManyField fields below. QuerySet iteration ¶ The QuerySet iteration was changed to immediately convert all fetched rows to Model objects. In Django 1.5 and earlier t ... ... 1.4.9, we've reverted this change and instead improved the speed of our PBKDF2 algorithm by not rehashing the key on every iteration. バグ修正 ¶ Fixed a data corruption bug with datetime_safe.datetime.combine (#21256). 目次 Django 1.4.9 リリースノート Rea ... ... s a handful of fixes. The biggest fix is for a memory leak introduced in Django 1.5. Under certain circumstances, repeated iteration over querysets could leak memory - sometimes quite a bit of it. If you'd like more information, the details are in our tic ... ... 1.5.5, we've reverted this change and instead improved the speed of our PBKDF2 algorithm by not rehashing the key on every iteration. Properly rotate CSRF token on login ¶ This behavior introduced as a security hardening measure in Django 1.5.2 did not wo ... ... 1.5.5, we've reverted this change and instead improved the speed of our PBKDF2 algorithm by not rehashing the key on every iteration. Properly rotate CSRF token on login ¶ This behavior introduced as a security hardening measure in Django 1.5.2 did not wo ... ... rip_tags() was changed to work iteratively. The problem is that the size of the input it's processing can increase on each iteration which results in an infinite loop in strip_tags() . This issue only affects versions of Python that haven't received a bug ... ... 8). Fixed a crash when a GeometryField uses a non-geometric widget (#21496). Fixed password hash upgrade when changing the iteration count (#21535). Fixed a bug in the debug view when the URLconf only contains one element (#21530). Re-added missing search ... 2026年10月08日